Learn R Programming

vfprogression (version 0.7.1)

vfseries: Combined Visual Field Series for General Progression Method

Description

Data

Usage

data(vfseries)

Arguments

Format

A data frame sample including the following visual field related measurement for two eyes, each with 10 follow-ups.

Examples

Run this code
# NOT RUN {
data(vfseries)
progression(vfseries)
progression(vfseries[vfseries$eyeid == 1,])
progression(vfseries[vfseries$eyeid == 2,])
progression(vfseries, method=c("cigts"))
progression.cigts(vfseries)
progression(vfseries, method=c('plr.nouri.2012', 'schell2014', 'vfi'))
# }

Run the code above in your browser using DataLab